@@ -4,6 +4,7 @@ import osm_bot_abstraction_layer.human_verification_mode as human_verification_m
 from osm_bot_abstraction_layer.split_into_packages import Package
 from osm_iterator.osm_iterator import Data
 import time
+import osmapi
 
 def splitter_generator(edit_element):
     def splitter_generated(element):
@@ -30,16 +31,47 @@ def build_changeset(is_in_manual_mode, changeset_comment, discussion_url, osm_wi
     return api
 
 def process_osm_elements_package(package, is_in_manual_mode, changeset_comment, discussion_url, osm_wiki_documentation_page, edit_element_function):
-    api = build_changeset(is_in_manual_mode, changeset_comment, discussion_url, osm_wiki_documentation_page)
+    changeset = None
     for element in package.list:
         data = modify_data_locally_and_show_changes(element.get_link(), edit_element_function)
         if is_edit_allowed(is_in_manual_mode, element.get_link()):
-            osm_bot_abstraction_layer.update_element(api, element.element.tag, data)
+            retry_remaining_attempts = 5
+            while retry_remaining_attempts > 0:
+                retry_remaining_attempts -= 1
+                try:
+                    if changeset == None:
+                        changeset = build_changeset(is_in_manual_mode, changeset_comment, discussion_url, osm_wiki_documentation_page)
+                    osm_bot_abstraction_layer.update_element(changeset, element.element.tag, data)
+                    break # completed succesfully, no need to repeat
+                except osmapi.ApiError as e:
+                    if is_exception_about_already_closed_changeset(e):
+                        changeset = None
+                        continue # ugly but... https://stackoverflow.com/a/2083996/4130619
+                    else:
+                        print("error! Paused for review. Press enter to continue.")
+                        input()
+                except Exception as e:
+                    print("some other exception happened")
         print()
         print()
-    api.ChangesetClose()
+    try:
+      changeset.ChangesetClose()
+    except osmapi.ApiError as e:
+      if is_exception_about_already_closed_changeset(e):
+        pass
+      else:
+        raise e
     sleep_after_edit(is_in_manual_mode)
 
+def is_exception_about_already_closed_changeset(exception):
+    print(str(exception))
+    print("was closed at" in str(exception))
+    print("******")
+    if "was closed at" in str(exception): # there is no more specific exception... https://github.com/metaodi/osmapi/issues/115
+      return True
+    else:
+      return False
+
 def is_edit_allowed(is_in_manual_mode, link):
     if is_in_manual_mode == False:
         return True
@@ -110,6 +142,7 @@ def run_simple_retagging_task(max_count_of_elements_in_one_changeset, objects_to
     osm = Data(objects_to_consider_query_storage_file)
     osm.iterate_over_data(splitter_generator(edit_element_function))
 
+    # list_of_elements is filled with above function, elements are osm_iterator.Element objects
     packages = Package.split_into_packages(list_of_elements, max_count_of_elements_in_one_changeset)
     if len(list_of_elements) == 0:
         print("no elements found for editing among", checked_element_count, "checked items, skipping!")
