@@ -42,6 +42,34 @@ def is_shop(tags):
         return True
     return is_any_matching_with_tag_listing(tags, shop_tag_listing())
 
+def is_tag_expected_for_recycling_place(key, value, tags):
+    expected_tags = {
+        # https://taginfo.openstreetmap.org/search?q=recycling%3A
+        'recycling_type': {'centre', 'container'},
+        'recycling:glass_bottles': {'yes'},
+        'recycling:paper': {'yes'},
+        'recycling:glass': {'yes'},
+        'recycling:clothes': {'yes'},
+        'recycling:cans': {'yes'},
+        'recycling:plastic': {'yes'},
+        'recycling:plastic_bottles': {'yes'},
+        'recycling:plastic_packaging': {'yes'},
+        'recycling:cardboard': {'yes'},
+        'recycling:shoes': {'yes'},
+        'recycling:batteries': {'yes'},
+        'recycling:scrap_metal': {'yes'},
+        'recycling:green_waste': {'yes'},
+        'recycling:paper_packaging': {'yes'},
+    }
+    if key in expected_tags:
+        if value in expected_tags.get(key):
+            return True
+    if key == "operator":
+        if value == "Polski Czerwony Krzyż":
+            if tags.get("recycling:clothes") == "yes":
+                return True
+    return False
+
 def is_settlement(tags):
     if tags.get('place') in ['hamlet', 'village', 'town', 'city']:
         return True
@@ -65,6 +93,8 @@ def is_indoor_poi(tags):
         return True
     if tags.get("tourism") in ["museum"]:
         return True
+    if tags.get('office') in valid_office_values():
+        return True
     return False
 
 def is_rentable_sleeping_place(tags):
@@ -104,7 +134,7 @@ def is_plant(tags):
         return True
     return False
 
-def is_taggable_with_species(tags):
+def is_taggable_with_taxon(tags):
     if is_plant(tags):
         return True
     if tags.get("attraction") in ["enclosure", "animal"]:
@@ -124,7 +154,10 @@ def is_doctor(tags):
     return is_any_matching_with_tag_listing(tags, doctor_tag_listing())
 
 def brandable_tag_listing():
-    return {'amenity': ["atm"]}
+    return {'amenity': ["atm", "motorcycle_rental"], 'office': valid_office_values()}
+
+def valid_office_values():
+    return ['insurance']
 
 def is_brandable(tags):
     return is_any_matching_with_tag_listing(tags, brandable_tag_listing())
@@ -437,12 +470,32 @@ def is_expected_tag(key, value, tags, special_expected):
         if key == "internet_access:fee":
             if value in ["yes", "no"]:
                 return True
-    if is_taggable_with_species(tags):
-        if key in ["species", "species:wikidata", "species:wikipedia"]:
+    if is_taggable_with_taxon(tags):
+        if key in ["species", "species:wikidata", "species:wikipedia",
+                   "genus", "genus:wikidata", "genus:wikipedia",
+                   "taxon", "taxon:wikidata", "taxon:wikipedia"]:
             return True
         for language_code in all_iso_639_1_language_codes():
             if key == "species:" + language_code:
                 return True
+    if tags and tags.get("natural") == "tree":
+        if key == "leaf_type":
+            if value in ["broadleaved", "needleleaved", "palm"]:
+                return True
+        if key == "leaf_cycle":
+            if value in ["deciduous", "evergreen", "semi_deciduous"]:
+                return True
+        if key == "denotation":
+            # https://taginfo.openstreetmap.org/keys/denotation#values
+            if value in ["natural_monument", "landmark", "urban", "avenue", "agricultural"]:
+                return True
+    elif is_plant(tags):
+        if key == "leaf_type":
+            if value in ["broadleaved", "needleleaved", "palm", "mixed"]:
+                return True
+        if key == "leaf_cycle":
+            if value in ["deciduous", "evergreen", "semi_deciduous", "mixed"]:
+                return True
     if tags.get('abandoned:man_made') == "mineshaft":
         if key in ["former_operator:wikidata", "former_operator:wikipedia"]:
             return True
@@ -452,6 +505,9 @@ def is_expected_tag(key, value, tags, special_expected):
                 return True
     if is_acceptable_source_tag(key, value, tags):
         return True
+    if tags.get("amenity") == "recycling":
+        if is_tag_expected_for_recycling_place(key, value, tags):
+            return True
     return False
 
 def smart_print_tag_dictionary(tags, special_expected={}):
