@@ -55,11 +55,38 @@ def get_data(id, type):
             return api.WayGet(id)
         if type == 'relation':
             return api.RelationGet(id)
+        if type == 'note':
+            return api.NoteGet(id)
     except osmapi.ElementDeletedApiError:
         return None
     assert(False)
 
+def close_note(noteId, comment):
+    api = get_api('bot_account')
+    api.NoteClose(noteId, comment)
+
 def update_element(api, type, data):
+    """
+    Updates object with the supplied data dict.
+
+    For nodes:
+        #!python
+        {
+            'id': id of node,
+            'lat': latitude of node,
+            'lon': longitude of node,
+            'tag': {},
+            'version': version number of node,
+        }
+
+    https://github.com/metaodi/osmapi/blob/master/osmapi/OsmApi.py#L308
+    https://github.com/metaodi/osmapi/blob/dccb636e1e07b56c936a454997bc2763fb1d8031/osmapi/OsmApi.py#L308
+
+    For ways?:
+
+    For relations?:
+    """
+
     try:
         if type == 'node':
             return api.NodeUpdate(data)
